#####################################
## LAB: Structural Equation Modeling
require(lavaan)

## Path Analysis
setwd("~/Documents/TEACHING/2019 Course AUS/Labs")
data = read.table("Lab 2 Data DairyCows.txt", header = T)
str(data)
plot(data)

## Path Model
path.Model = '
	MilkYield ~ Disease
	SCS ~ Disease
	DaysOpen ~ SCS + MilkYield + Disease
'
fit = sem(path.Model, data = data)
show(fit)
summary(fit)
summary(fit, fit.measures = TRUE)
summary(fit, fit.measures = TRUE, standardized = TRUE)

## Alternative Path Model
path.Model2 = '
	MilkYield ~ Disease
	SCS ~ Disease
	DaysOpen ~ SCS + MilkYield
'
fit2 = sem(path.Model2, data = data); show(fit2)

# Comparing Path Models (Nested Models)
anova(fit,fit2)

# Total Effect Disease -> Fertility
path.Model = '
	MilkYield ~ a1*Disease
	SCS ~ a2*Disease
	DaysOpen ~ a3*SCS + a4*MilkYield + a5*Disease
	totalEffect := a1*a4 + a2*a3 + a5
'
fit = sem(path.Model, data = data); show(fit)
summary(fit)

## Statistically Equivalent Models
path.Model.eq1 = '
	MilkYield ~~ Disease
	SCS ~ Disease
	DaysOpen ~ SCS + MilkYield + Disease
'
fit.eq1 = sem(path.Model.eq1, data = data)
fitMeasures(fit.eq1, c("chisq","df","rmsea","srmr","cfi","tli","aic","bic"))
fitMeasures(fit, c("chisq","df","rmsea","srmr","cfi","tli","aic","bic"))

path.Model.eq2 = '
	MilkYield ~ Disease
	SCS ~~ Disease
	DaysOpen ~ SCS + MilkYield + Disease
'
fit.eq2 = sem(path.Model.eq2, data = data)
fitMeasures(fit.eq2, c("chisq","df","rmsea","srmr","cfi","tli","aic","bic"))
fitMeasures(fit.eq1, c("chisq","df","rmsea","srmr","cfi","tli","aic","bic"))
fitMeasures(fit, c("chisq","df","rmsea","srmr","cfi","tli","aic","bic"))

###############################
## Confirmatory Factor Analysis
require(lavaan)
setwd("~/Documents/TEACHING/2019 Course AUS/Labs/")
data = read.table("Lab 2 Data Pork.txt", header = T)
str(data)

## Latent Variable: Primal Cuts
cfaCuts = '
	cuts =~ Ham + Loin + Boston
'
fit = cfa(cfaCuts, data = data, std.lv = TRUE)
show(fit)
summary(fit)

## CFA Model with 3 Latent Variables
model.cfa = '
	cuts =~ Ham + Loin + Boston
	fat =~ ribOne + lastRib + lastLum
	quality =~ Marbling + Firmness + dripLoss
'
fit = cfa(model.cfa, data = data, std.lv = TRUE)
show(fit)
summary(fit)
b
### From CFA to SEM
model.sem = '
	cuts =~ Ham + Loin + Boston
	fat =~ ribOne + lastRib + lastLum
	quality =~ Marbling + Firmness + dripLoss
	quality ~ cuts + fat
	
'
fit = sem(model.sem, data = data, std.lv = TRUE)
show(fit)
summary(fit)
fitMeasures(fit, c("chisq","df","rmsea","srmr","cfi","tli","aic","bic"))

model.sem.0 = '
	cuts =~ Ham + Loin + Boston
	fat =~ ribOne + lastRib + lastLum
	quality =~ Marbling + Firmness + dripLoss
	quality ~ cuts + fat
	cuts ~~ 0*fat
'
fit.0 = sem(model.sem.0, data = data, std.lv = TRUE)
show(fit.0)
summary(fit)
fitMeasures(fit, c("chisq","df","rmsea","srmr","cfi","tli","aic","bic"))

# Alternative SEM (1)
model.sem.1 = '
	cuts =~ Ham + Loin + Boston
	fat =~ ribOne + lastRib + lastLum
	quality =~ Marbling + Firmness + dripLoss
	quality ~ cuts
	fat ~ cuts
'
fit1 = sem(model.sem.1, data = data, std.lv = TRUE)
show(fit1)
summary(fit1)

fitMeasures(fit, c("chisq","df","rmsea","srmr","cfi","tli","aic","bic"))
fitMeasures(fit1, c("chisq","df","rmsea","srmr","cfi","tli","aic","bic"))

# Alternative SEM (2)
model.sem.2 = '
	cuts =~ Ham + Loin + Boston
	fat =~ ribOne + lastRib + lastLum
	quality =~ Marbling + Firmness + dripLoss
	fat ~ cuts
	quality ~ fat
'
fit2 = sem(model.sem.2, data = data, std.lv = TRUE)
show(fit2)

fitMeasures(fit, c("chisq","df","rmsea","srmr","cfi","tli","aic","bic"))
fitMeasures(fit2, c("chisq","df","rmsea","srmr","cfi","tli","aic","bic"))



